# nBomber
SMS BOMBING TOOL WITH HAVING 50,000 MESSAGE SENDING CAPACITY AT A TIME.

<h2 align="center"><u>nBomber</u></h2>

<p align="center">A free and open-source SMS/Call bombing application</p>

<p align="center">
<br>
</p>



![image1](.images/image1.png)
![image2](.images/image2.png)
![image3](.images/image3.png)
![image4](.images/image4.png)



### [+] Description
> **SMS BOMBING TOOL WITH HAVING 50,000 MESSAGE SENDING CAPACITY AT A TIME.**

> **Now can see Name, Simcard, Region, Gender, and E-Mail of Target Number .**

•The application requires active internet connection to contact the APIs

•You would not be charged for any SMS/calls dispatched as a consequence of this script

•For best performance, use single thread with considerable delay time.

•Always ensure that you are using the latest version of nBomber and have Python 3.

•This application must not be used to cause harm/discomfort/trouble to others.

•By using this, you agree that you cannot hold the contributors responsible for any misuse.

### [+] Installation
Run these commands to Install nBomber.

```shell script
pip install nBomber
```

## [+] USAGE

To use the nBomber type the following commands:
```shell script
nBomber
```

## FAQ
**Q:** Poor Internet Connection Detected:

**A:** Here are a few stuff you can try:
- Check your connection.
- Make sure `openssl` is installed.
- Try to `ping` any remote site/address to be sure.
- Try to reinstall if nothing works.
##
**Q:** How many COUNTRIES do you support?

**A:** Most Countries are supported for SMS and only India for calls. The SMS delivery rate might be different for different countries.
##
**Q:** How many COUNTRIES Do you support ?

**A:** Most Countries are supported for SMS and only India for calls. The SMS delivery rate might be different for different countries.
##
**Q:** How to get protection ?

**A:** Use OTP blockers and activate DND.
##
**Q:** What is used to show Target Number Details(Name etc.) ?
**A:** We use Truecaller API for getting Target Number Details.
##
